@@ -2,7 +2,7 @@ use image::ImageError;
 
 use crate::Error;
 
-use super::context::Context;
+use super::context::{Context, ImageOutputFormat};
 use super::element::{Element, Img, Line, Text};
 use super::font::{create_font, Font, FontContext, FontIndexStore};
 use super::glyph::Glyph;
@@ -169,10 +169,16 @@ impl OGImageWriter {
         Ok(())
     }
 
+    /// Return the raw image data.
     pub fn into_vec(self) -> Result<Vec<u8>, Error> {
         self.context.into_vec()
     }
 
+    /// Return the encoded raw image data.
+    pub fn encode(self, format: ImageOutputFormat) -> Result<Vec<u8>, Error> {
+        self.context.encode(format)
+    }
+
     fn paint_img(&mut self, img: Img) -> Result<(), Error> {
         self.context.draw_image(img.buf, img.rect.x, img.rect.y)
     }
@@ -249,20 +255,17 @@ impl OGImageWriter {
                         Some(glyph) => match &glyph.font_index_store {
                             FontIndexStore::Global(idx) => {
                                 let mut context = &mut self.context;
-                                self.font_context.with(
-                                    idx,
-                                    |font| {
-                                        render_text(
-                                            text,
-                                            &mut range,
-                                            font,
-                                            &mut context,
-                                            &mut current_width,
-                                            style,
-                                            line,
-                                        )
-                                    },
-                                )?;
+                                self.font_context.with(idx, |font| {
+                                    render_text(
+                                        text,
+                                        &mut range,
+                                        font,
+                                        &mut context,
+                                        &mut current_width,
+                                        style,
+                                        line,
+                                    )
+                                })?;
                             }
                             FontIndexStore::Parent(_) => {
                                 let font = match &text_elm.font {
@@ -316,19 +319,16 @@ impl OGImageWriter {
                     Some(glyph) => match &glyph.font_index_store {
                         FontIndexStore::Global(idx) => {
                             let context = &mut self.context;
-                            self.font_context.with(
-                                idx,
-                                |font| {
-                                    context.draw_text(
-                                        style.color.as_image_rgba(),
-                                        line.rect.x + current_width,
-                                        line.rect.y,
-                                        style.font_size,
-                                        font,
-                                        &text[range.clone()],
-                                    )
-                                },
-                            )?;
+                            self.font_context.with(idx, |font| {
+                                context.draw_text(
+                                    style.color.as_image_rgba(),
+                                    line.rect.x + current_width,
+                                    line.rect.y,
+                                    style.font_size,
+                                    font,
+                                    &text[range.clone()],
+                                )
+                            })?;
                         }
                         FontIndexStore::Parent(_) => {
                             let font = match &text_elm.font {
